==> cms-db_v0.7.5.tar.gz: admin/tabs.js <==
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */


var tabs = new Array();
var activetab = "";
function IframeOnLoad(tab) {
	var url = document.getElementById("iframe_"+tab).src;
	if (url.indexOf("?") != -1) {
		var scriptname = url.substring(url.lastIndexOf("/")+1, url.indexOf("?"));
	} else {
		var scriptname = url.substr(url.lastIndexOf("/")+1);
	}
	if (scriptname == "pages.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/pages.png"); }
	else if (scriptname == "files.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/files.png"); }
	else if (scriptname == "includes.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/includes.png"); }
	else if (scriptname == "settings.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/settings.png"); }
	else if (scriptname == "template.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/template.png"); }
	else if (scriptname == "space.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/space.png"); }
	else if (scriptname == "fileperms.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/fileperms.png"); }
	else if (scriptname == "backup.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/backup.png"); }
	else if (scriptname == "guestbook.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/guestbook.png"); }
	else if (scriptname == "blog.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/blog.png"); }
	else if (scriptname == "stats.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/stats.png"); }
	else if (scriptname == "recyclebin.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/recyclebin.png"); }
	else if (url.indexOf("index.php") != -1) { $("#tab_"+tab+">.icon").attr("src", "big-icons/preview.png"); }
	else if (scriptname == "version.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/about.png"); }
	if (!jQuery.browser.msie) {
		iframecontents = $("#iframe_"+tab).contents();
		try {
			var title = iframecontents.find("title").text();
			if (title.length > 17) {
				label = title.slice(0, 15)+'...';
			} else {
				label = title;
			}
			$("#title_"+tab).text(label+"\u00a0").attr("title", title);
			if (iframecontents.find("head").html().search(/name="generator" content="cms -db"/) == -1) {
				var i = 0;
				iframecontents.find("a").each(function () {
					var location = $(this).attr("href");
					var clickevent = $(this).attr("onclick");
					var disabled = $(this).hasClass("nonewtab");
					if (clickevent == undefined && location.substr(0,11) != 'javascript:' && location != '#' && location != 'http://www.wymeditor.org/' && !disabled) {
						if ($(this).find("img").size() != 0) {
							var classname = "newtabbutton2";
						} else {
							var classname = "newtabbutton";
						}
						$(this)
							.before(	'<a	class="'+classname+'"' +
										'	onclick="return parent.newTab(\''+location+'\')"' +
										'	href="frame.php?'+php_session_id+'#open;'+location+'">' +
										'	<img src="transparent.png" id="newtabbutton'+i+'" width="16" height="16" alt="" />' +
										'</a>' );
						if (location.substr(0,7) != 'http://') {
							$(this).attr("href", "frame.php?"+php_session_id+"#open;"+location);
							// $(this).attr("onclick", "return parent.openInActiveTab('"+location+"')")
							// doesn't work in Webkit (tested with Chromium)
							$(this).attr("rel", location);
							$(this).click(function() { return openInActiveTab($(this).attr("rel")); });
						}
						$(this).attr("onmouseover", "document.getElementById('newtabbutton"+i+"').className='active'");
						$(this).attr("onmouseout", "document.getElementById('newtabbutton"+i+"').className=''");
						++i;
					}
				});
			}
		} catch (e) {
			$("#title_"+tab).text("undefined\u00a0").attr("title", "Error: The title could not be set.");
		}
	} else {
		var iframe = document.getElementById('iframe_'+tab);
		if (iframe.contentDocument) {
			var iframecontent = iframe.contentDocument;
		} else if (iframe.contentWindow) {
			var iframecontent = iframe.contentWindow.document;
		} else {
			$("#title_"+tab).text("undefined\u00a0").attr("title", "Error: The title could not be set.");
		}
		try {
			var title = iframecontent.title;
			if (title.length > 17) {
				label = title.slice(0, 15)+'...';
			} else {
				label = title;
			}
			$("#title_"+tab).text(label+"\u00a0").attr("title", title);
		} catch (e) {
			$("#title_"+tab).text("undefined\u00a0").attr("title", "Error: The title could not be set.");
		}
	}
	resizeIframes();
}
function IframeOnUnload(tab) {
	$("#title_"+tab).text("loading...\u00a0");
}

function newTab(source, id) {
	var id = !id?"auto":id;
	if (id == "auto") {
		var min = 0;
		var max = 100000;
		var random = Math.round(Math.random() * (max - min)) + min;
	} else {
		var random = id;
	}
	/* Start Tab */
		$("#tabs").append(
			'<a class="tab" id="tab_' + random + '" href="javascript:openTab(\'' + random + '\')">' +
			'	<span class="tableft"></span>' +
			'	<img src="page.png" class="icon" alt="" style="border: none; margin-top: 2px; width: 16px; height: 16px" />' +
			'	<span id="title_' + random + '" class="title">loading...\u00a0</span>' +
			'	<img src="close.png" alt="' + label_close_localized + '" title="' + label_close_localized + '" onclick="closeTab(\'' + random + '\'); return false" style="border: none; margin-top: 2px" />' +
			'	<span class="tabright"></span>' +
			'</a>');
		// Work-around for jQuery 1.2.6 (see main.js)
		$('#tab_'+random).click(function() {
			$(this).blur();
		});
		// End of work-around
		$("#tab_"+random).css('opacity', 0).animate({ opacity: 1 }, 500);
		$("#title_"+random).hide().animate({ width: "show" }, 500);
	/* Ende Tab */
	/* Start Iframe */
		var height_tabs = document.getElementById("tabs").offsetHeight;
		if (navigator.appName.indexOf("Explorer") != -1) {
			var cwidth = document.documentElement.clientWidth;
			var cheight = document.documentElement.clientHeight;
			var ifrmwidth = cwidth;
			var ifrmheight = cheight - 24 - height_tabs;
		} else {
			var iwidth = window.innerWidth;
			var iheight = window.innerHeight;
			var ifrmwidth = iwidth;
			var ifrmheight = iheight - 24 - height_tabs;
		}
		var ifrmtop = 24 + height_tabs;
		$("#iframes").append('<iframe src="' + source + '" id="iframe_' + random + '" onload="IframeOnLoad(\'' + random + '\')" onunload="IframeOnUnload(\'' + random + '\')" style="left: 0px; top: ' + ifrmtop + 'px; width: ' + ifrmwidth + 'px; height: ' + ifrmheight + 'px"></iframe>');
		/*if (navigator.appName.indexOf("Explorer") != -1) {
			window.setInterval("IframeOnLoad('"+random+"')", 1000);
			window.setTimeout("IframeOnLoad('"+random+"')", 100);
		}*/
		/* onunload in IE deaktivieren ? */
	/* Ende Iframe */
	tabs.push(random);
	if (window.location.hash.indexOf(random+";") == -1) {
		window.location.hash += random+";";
	}
	openTab(random);
	return false;
}
function openInActiveTab(source) {
	if (activetab && document.getElementById('iframe_'+activetab)) {
		$("#iframe_"+activetab).attr("src", source);
	} else {
		newTab(source)
	}
	return false;
}
function hideActiveTab() {
	if (activetab && document.getElementById('tab_'+activetab)) {
		$("#tab_"+activetab).removeClass("activetab");
		$("#iframe_"+activetab).hide();
	}
}
function openTab(tab) {
	hideActiveTab();
	$("#tab_"+tab).addClass("activetab");
	$("#iframe_"+tab).show();
	activetab = tab;
}
function closeTab(tab) {
	$("#tab_"+tab).animate({ opacity: 0 }, 500).queue(function () { $("#tab_"+tab).remove(); resizeIframes(); });
	$("#title_"+tab).animate({ width: 0 }, 500);
	$("#iframe_"+tab).remove();
	var oldtablist = tabs;
	tabs = new Array();
	for (var i = 0; i < oldtablist.length; ++i) {
		if (oldtablist[i] != tab) {
			tabs.push(oldtablist[i]);
		}
	}
	window.location.hash = window.location.hash.replace(tab+";", "");
}
function resizeIframes() {
	var height_tabs = document.getElementById("tabs").offsetHeight;
	if (navigator.appName.indexOf("Explorer") != -1) {
		var cwidth = document.documentElement.clientWidth;
		var cheight = document.documentElement.clientHeight;
		var ifrmwidth = cwidth;
		var ifrmheight = cheight - 24 - height_tabs;
	} else {
		var iwidth = window.innerWidth;
		var iheight = window.innerHeight;
		var ifrmwidth = iwidth;
		var ifrmheight = iheight - 24 - height_tabs;
	}
	var ifrmtop = 24 + height_tabs;
	var iframe;
	var framewidth;
	var frameheight;
	for (var i = 0; i < tabs.length; ++i) {
		$("#iframe_"+tabs[i])
			.css("width", ifrmwidth + "px")
			.css("height", ifrmheight + "px")
			.css("top", ifrmtop + "px");
	}
}
function restoreTabs() {
	var hash = window.location.hash.split(";");
	if (hash[0] == '#tabs' || hash[0] == 'tabs') {
		hash.shift();
		hash.pop();
		for (var i = 0; i < hash.length; ++i) {
			newTab("javascript:document.write(\""+hash[i]+"\");", hash[i]);
		}
	} else if (hash[0] == '#open' || hash[0] == 'open') {
		window.location.hash = "tabs;"
		newTab(hash[1], '0');
	}
}
/*
 * Tab Switcher
 * Super + Tab / AltGr + Tab
 */
modifierkeypressed = 0;
document.onkeydown = function(e) {
	if (navigator.appName.indexOf("Explorer") != -1) {
		var code = window.event.keyCode;
	} else {
		var code = e.which;
	}
	if (code == 9 && modifierkeypressed == 1) {
		for (var i = 0; i < tabs.length; ++i) {
			if (tabs[i] == activetab) {
				if (i < tabs.length-1) {
					i = i+1;
				} else {
					i = 0;
				}
				openTab(tabs[i]);
				break;
			}
		}
	}
	if (code == 0) {
		modifierkeypressed = 1;
	}
}
document.onkeyup = function(e) {
	if (navigator.appName.indexOf("Explorer") != -1) {
		var code = window.event.keyCode;
	} else {
		var code = e.which;
	}
	if (code == 0) {
		modifierkeypressed = 0;
	}
}

==> cms-db_v0.7.9.tar.gz: admin/tabs.js <==
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */


var tabs = new Array();
var activetab = "";
function IframeOnLoad(tab) {
	var url = document.getElementById("iframe_"+tab).src;
	if (url.indexOf("?") != -1) {
		var scriptname = url.substring(url.lastIndexOf("/")+1, url.indexOf("?"));
	} else {
		var scriptname = url.substr(url.lastIndexOf("/")+1);
	}
	if (scriptname == "pages.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/pages.png"); }
	else if (scriptname == "files.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/files.png"); }
	else if (scriptname == "includes.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/includes.png"); }
	else if (scriptname == "settings.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/settings.png"); }
	else if (scriptname == "template.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/template.png"); }
	else if (scriptname == "space.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/space.png"); }
	else if (scriptname == "fileperms.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/fileperms.png"); }
	else if (scriptname == "backup.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/backup.png"); }
	else if (scriptname == "guestbook.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/guestbook.png"); }
	else if (scriptname == "blog.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/blog.png"); }
	else if (scriptname == "stats.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/stats.png"); }
	else if (scriptname == "recyclebin.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/recyclebin.png"); }
	else if (url.indexOf("index.php") != -1) { $("#tab_"+tab+">.icon").attr("src", "big-icons/preview.png"); }
	else if (scriptname == "version.php") { $("#tab_"+tab+">.icon").attr("src", "big-icons/about.png"); }
	if (!jQuery.browser.msie) {
		iframecontents = $("#iframe_"+tab).contents();
		try {
			var title = iframecontents.find("title").text();
			if (title.length > 17) {
				label = title.slice(0, 15)+'...';
			} else {
				label = title;
			}
			$("#title_"+tab).text(label+"\u00a0").attr("title", title);
			if (iframecontents.find("head").html().search(/name="generator" content="cms -db"/) == -1) {
				var i = 0;
				iframecontents.find("a").each(function () {
					var location = $(this).attr("href");
					var clickevent = $(this).attr("onclick");
					var disabled = $(this).hasClass("nonewtab");
					if (clickevent == undefined && location.substr(0,11) != 'javascript:' && location != '#' && location != 'http://www.wymeditor.org/' && !disabled) {
						//if ($(this).find("img").size() != 0) {
						if ($(this).html().substr(0,4) == "<img") {
							var classname = "newtabbutton2";
						} else {
							var classname = "newtabbutton";
						}
						$(this)
							.before(	'<a	class="'+classname+'"' +
										'	onclick="return parent.newTab(\''+location+'\')"' +
										'	href="frame.php?'+php_session_id+'#open;'+location+'">' +
										'	<img src="transparent.png" id="newtabbutton'+i+'" width="16" height="16" alt="" />' +
										'</a>' );
						if (location.substr(0,7) != 'http://') {
							$(this).attr("href", "frame.php?"+php_session_id+"#open;"+location);
							// $(this).attr("onclick", "return parent.openInActiveTab('"+location+"')")
							// doesn't work in Webkit (tested with Chromium)
							$(this).attr("rel", location);
							$(this).click(function() { return openInActiveTab($(this).attr("rel")); });
						}
						$(this).attr("onmouseover", "document.getElementById('newtabbutton"+i+"').className='active'");
						$(this).attr("onmouseout", "document.getElementById('newtabbutton"+i+"').className=''");
						++i;
					}
				});
			}
		} catch (e) {
			$("#title_"+tab).text("undefined\u00a0").attr("title", "Error: The title could not be set.");
		}
	} else {
		var iframe = document.getElementById('iframe_'+tab);
		if (iframe.contentDocument) {
			var iframecontent = iframe.contentDocument;
		} else if (iframe.contentWindow) {
			var iframecontent = iframe.contentWindow.document;
		} else {
			$("#title_"+tab).text("undefined\u00a0").attr("title", "Error: The title could not be set.");
		}
		try {
			var title = iframecontent.title;
			if (title.length > 17) {
				label = title.slice(0, 15)+'...';
			} else {
				label = title;
			}
			$("#title_"+tab).text(label+"\u00a0").attr("title", title);
		} catch (e) {
			$("#title_"+tab).text("undefined\u00a0").attr("title", "Error: The title could not be set.");
		}
	}
	resizeIframes();
}
function IframeOnUnload(tab) {
	$("#title_"+tab).text("loading...\u00a0");
}

function newTab(source, id) {
	var id = !id?"auto":id;
	if (id == "auto") {
		var min = 0;
		var max = 100000;
		var random = Math.round(Math.random() * (max - min)) + min;
	} else {
		var random = id;
	}
	/* Start Tab */
		$("#tabs").append(
			'<a class="tab" id="tab_' + random + '" href="javascript:openTab(\'' + random + '\')">' +
			'	<span class="tableft"></span>' +
			'	<img src="page.png" class="icon" alt="" style="border: none; margin-top: 2px; width: 16px; height: 16px" />' +
			'	<span id="title_' + random + '" class="title">loading...\u00a0</span>' +
			'	<img src="close.png" alt="' + label_close_localized + '" title="' + label_close_localized + '" onclick="closeTab(\'' + random + '\'); return false" style="border: none; margin-top: 2px" />' +
			'	<span class="tabright"></span>' +
			'</a>');
		// Work-around for jQuery 1.2.6 (see main.js)
		$('#tab_'+random).click(function() {
			$(this).blur();
		});
		// End of work-around
		$("#tab_"+random).css('opacity', 0).animate({ opacity: 1 }, 500);
		$("#title_"+random).hide().animate({ width: "show" }, 500);
	/* Ende Tab */
	/* Start Iframe */
		var height_tabs = document.getElementById("tabs").offsetHeight;
		if (navigator.appName.indexOf("Explorer") != -1) {
			var cwidth = document.documentElement.clientWidth;
			var cheight = document.documentElement.clientHeight;
			var ifrmwidth = cwidth;
			var ifrmheight = cheight - 24 - height_tabs;
		} else {
			var iwidth = window.innerWidth;
			var iheight = window.innerHeight;
			var ifrmwidth = iwidth;
			var ifrmheight = iheight - 24 - height_tabs;
		}
		var ifrmtop = 24 + height_tabs;
		$("#iframes").append('<iframe src="' + source + '" id="iframe_' + random + '" onload="IframeOnLoad(\'' + random + '\')" onunload="IframeOnUnload(\'' + random + '\')" style="left: 0px; top: ' + ifrmtop + 'px; width: ' + ifrmwidth + 'px; height: ' + ifrmheight + 'px"></iframe>');
		/*if (navigator.appName.indexOf("Explorer") != -1) {
			window.setInterval("IframeOnLoad('"+random+"')", 1000);
			window.setTimeout("IframeOnLoad('"+random+"')", 100);
		}*/
		/* onunload in IE deaktivieren ? */
	/* Ende Iframe */
	tabs.push(random);
	if (window.location.hash.indexOf(random+";") == -1) {
		window.location.hash += random+";";
	}
	openTab(random);
	return false;
}
function openInActiveTab(source) {
	if (activetab && document.getElementById('iframe_'+activetab)) {
		$("#iframe_"+activetab).attr("src", source);
	} else {
		newTab(source)
	}
	return false;
}
function hideActiveTab() {
	if (activetab && document.getElementById('tab_'+activetab)) {
		$("#tab_"+activetab).removeClass("activetab");
		$("#iframe_"+activetab).hide();
	}
}
function openTab(tab) {
	hideActiveTab();
	$("#tab_"+tab).addClass("activetab");
	$("#iframe_"+tab).show();
	activetab = tab;
}
function closeTab(tab) {
	$("#tab_"+tab).animate({ opacity: 0 }, 500).queue(function () { $("#tab_"+tab).remove(); resizeIframes(); });
	$("#title_"+tab).animate({ width: 0 }, 500);
	$("#iframe_"+tab).remove();
	var oldtablist = tabs;
	tabs = new Array();
	for (var i = 0; i < oldtablist.length; ++i) {
		if (oldtablist[i] != tab) {
			tabs.push(oldtablist[i]);
		}
	}
	window.location.hash = window.location.hash.replace(tab+";", "");
}
function resizeIframes() {
	var height_tabs = document.getElementById("tabs").offsetHeight;
	if (navigator.appName.indexOf("Explorer") != -1) {
		var cwidth = document.documentElement.clientWidth;
		var cheight = document.documentElement.clientHeight;
		var ifrmwidth = cwidth;
		var ifrmheight = cheight - 24 - height_tabs;
	} else {
		var iwidth = window.innerWidth;
		var iheight = window.innerHeight;
		var ifrmwidth = iwidth;
		var ifrmheight = iheight - 24 - height_tabs;
	}
	var ifrmtop = 24 + height_tabs;
	var iframe;
	var framewidth;
	var frameheight;
	for (var i = 0; i < tabs.length; ++i) {
		$("#iframe_"+tabs[i])
			.css("width", ifrmwidth + "px")
			.css("height", ifrmheight + "px")
			.css("top", ifrmtop + "px");
	}
}
function restoreTabs() {
	var hash = window.location.hash.split(";");
	if (hash[0] == '#tabs' || hash[0] == 'tabs') {
		hash.shift();
		hash.pop();
		for (var i = 0; i < hash.length; ++i) {
			newTab("javascript:document.write(\""+hash[i]+"\");", hash[i]);
		}
	} else if (hash[0] == '#open' || hash[0] == 'open') {
		window.location.hash = "tabs;"
		newTab(hash[1], '0');
	}
}
/*
 * Tab Switcher
 * Super + Tab / AltGr + Tab
 */
modifierkeypressed = 0;
document.onkeydown = function(e) {
	if (navigator.appName.indexOf("Explorer") != -1) {
		var code = window.event.keyCode;
	} else {
		var code = e.which;
	}
	if (code == 9 && modifierkeypressed == 1) {
		for (var i = 0; i < tabs.length; ++i) {
			if (tabs[i] == activetab) {
				if (i < tabs.length-1) {
					i = i+1;
				} else {
					i = 0;
				}
				openTab(tabs[i]);
				break;
			}
		}
	}
	if (code == 0) {
		modifierkeypressed = 1;
	}
}
document.onkeyup = function(e) {
	if (navigator.appName.indexOf("Explorer") != -1) {
		var code = window.event.keyCode;
	} else {
		var code = e.which;
	}
	if (code == 0) {
		modifierkeypressed = 0;
	}
}
